@@ -1,18 +1,18 @@
 # Copyrights 2007-2008 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.03.
+# Pod stripped from pm file by OODoc 1.04.
 
 use warnings;
 use strict;
 
 package Log::Report::Util;
 use vars '$VERSION';
-$VERSION = '0.15';
+$VERSION = '0.16';
 use base 'Exporter';
 
-our @EXPORT = qw/@reasons %reason_code parse_locale expand_reasons
-  escape_chars unescape_chars/;
+our @EXPORT = qw/@reasons %reason_code
+  parse_locale expand_reasons escape_chars unescape_chars/;
 
 use Log::Report 'log-report', syntax => 'SHORT';
 
